package vendoerivendo.model;

public class MyAnnuncio implements Annuncio, Comparable<Annuncio> {

	private Prodotto prodotto;
	private Estetica estetica;
	private double sconto;

	public MyAnnuncio(Prodotto prodotto, Estetica estetica, double sconto) {
		if (prodotto==null) throw new IllegalArgumentException("null product");
		if (estetica==null) throw new IllegalArgumentException("null appearance");
		if (sconto < 0 || sconto > 1) throw new IllegalArgumentException("discount not valid");
		this.prodotto = prodotto;
		this.estetica = estetica;
		this.sconto = sconto;
	}

	public int compareTo(Annuncio that) {
		//ordina gli annunci per categoria (crescente), e in subordine 
		// per estetica (decrescente) e prezzo (crescente);
		
		int categoryCompare = this.getCategoriaMerceologica().compareTo(that.getCategoriaMerceologica());
		if (categoryCompare != 0)
			return categoryCompare;
		
		int esteticaCompare = this.getEstetica().compareTo(that.getEstetica());
		if (esteticaCompare != 0)
			return esteticaCompare;
		
		double p1 = this.getPrezzo(), p2= that.getPrezzo();
		if (p1<p2) 
			return -1; 
		if (p1>p2) 
			return 1;
		return 0;
	}
	
	@Override
	public Prodotto getProdotto() {
		return prodotto;
	}

	@Override
	public CategoriaMerceologica getCategoriaMerceologica() {
		return prodotto.getCategoriaMerceologica();
	}

	@Override
	public Estetica getEstetica() {
		return estetica;
	}

	@Override
	public double getSconto() {
		return sconto;
	}

	@Override
	public double getPrezzo() {
		return getProdotto().getValore() * (1 - getSconto());
	}
	
	@Override
	public String toString(){
		return estetica + " " + prodotto.toString() + ", offerto a soli  " + getPrezzo();
	}

}
