package vendoerivendo.ui;

import javax.swing.*;

import vendoerivendo.controller.Controller;
import vendoerivendo.model.Estetica;
import vendoerivendo.model.Prodotto;
import vendoerivendo.model.Annuncio;

import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.*;
import java.text.NumberFormat;

public class AnnunciFrame extends JFrame implements ActionListener {

	private static final long serialVersionUID = 1L;

	private JPanel mainPanel;
	private JComboBox<Prodotto> comboProdotti;
	private JComboBox<Estetica> comboEstetica;
	private JFormattedTextField inputSconto;
	private JTextArea output;
	private JButton genera, stampa;
	private Controller controller;

	public AnnunciFrame(Controller controller) {
		this.controller = controller;
		initGUI();
		setSize(550, 280);
	}

	private void initGUI() {

		mainPanel = new JPanel();
		getContentPane().add(mainPanel);

		setTitle("Vendo e Rivendo");
		setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);

		// ---------------------
		mainPanel.add(new JLabel("Prodotti:        "));
		comboProdotti = new JComboBox<>(controller.getListaProdotti().toArray(new Prodotto[1]));
		comboProdotti.setPreferredSize(new Dimension(500, 20));
		comboProdotti.setSelectedIndex(-1);
		mainPanel.add(comboProdotti);
		// ---------------------
		mainPanel.add(new JLabel("Estetica:  "));
		comboEstetica = new JComboBox<>(Estetica.values());
		comboEstetica.setSelectedIndex(-1);
		mainPanel.add(comboEstetica);
		// ---------------------
		mainPanel.add(new JLabel("Sconto (%): "));
		NumberFormat format = NumberFormat.getPercentInstance();
		format.setMaximumFractionDigits(0);
		inputSconto = new JFormattedTextField(format);
		inputSconto.setPreferredSize(new Dimension(80, 20));
//		inputSconto.setInputVerifier(
//		new InputVerifier (){
//	         public boolean verify(JComponent input) {
//	        	 JFormattedTextField tf = (JFormattedTextField) input;
//	             return tf.getText().endsWith("%");
//	         }
//	     });
		mainPanel.add(inputSconto);
		// ---------------------
		Box box = Box.createVerticalBox();// new Box(BoxLayout.Y_AXIS);
		genera = new JButton("Genera annuncio");
		genera.addActionListener(this);
		box.add(genera);
		box.add(new JLabel("Annuncio: "));
		output = new JTextArea();
		output.setLineWrap(true);
		output.setPreferredSize(new Dimension(500, 50));
		box.add(output);
		stampa = new JButton("Stampa annuncio");
		stampa.addActionListener(this);
		box.add(stampa);
		mainPanel.add(box);
	}

	public void actionPerformed(ActionEvent e) {
		if (e.getSource() == genera) {
			Annuncio annuncio = generaAnnuncio();
			mostraAnnuncio(annuncio);
		} else if (e.getSource() == stampa) {
			Annuncio annuncio = generaAnnuncio();
			stampaAnnuncio(annuncio);
		}
	}

	private void mostraAnnuncio(Annuncio annuncio) {
		if (annuncio != null)
			output.setText(annuncio.toString());
	}

	private void stampaAnnuncio(Annuncio annuncio) {
		if (annuncio == null)
			return;
		
		JFileChooser chooser = new JFileChooser();
		// chooser.setDialogType(JFileChooser.SAVE_DIALOG);
		int returnVal = chooser.showSaveDialog(this);
		if (returnVal == JFileChooser.APPROVE_OPTION) {
			File file = chooser.getSelectedFile();
			try (PrintWriter pw = new PrintWriter(file)) {
				pw.println(annuncio.toString());
			} catch (FileNotFoundException e1) {
				e1.printStackTrace();
			}
		}
	}

	private Annuncio generaAnnuncio() {
		Prodotto prodotto = (Prodotto) comboProdotti.getSelectedItem();
		Estetica estetica = (Estetica) comboEstetica.getSelectedItem();
		Number sconto = (Number)inputSconto.getValue();
		if (prodotto == null || estetica == null) {
			JOptionPane.showMessageDialog(this, "Prodotto o estetica non compilati", "Attenzione", JOptionPane.WARNING_MESSAGE);
			return null;
		}
		if (sconto == null) {
			JOptionPane.showMessageDialog(this, "Lo sconto dev'essere una percentuale (es. 25%)", "Attenzione", JOptionPane.WARNING_MESSAGE);
			return null;
		} else if (sconto.doubleValue() < 0 || sconto.doubleValue() >= 1) {
			JOptionPane.showMessageDialog(this, "Lo sconto dev'essere compreso fra 0 e 100 (escluso)", "Attenzione", JOptionPane.WARNING_MESSAGE);
			return null;
		}
		return controller.generaAnnuncio(prodotto, estetica, sconto.doubleValue());
	}
}